.PHONY: ssh-init-hosts
ssh-init-hosts:
	ssh -o StrictHostKeyChecking=no cp01.$(TF_VAR_dns_domain) echo "Hello World"
	ssh -o StrictHostKeyChecking=no cp02.$(TF_VAR_dns_domain) echo "Hello World"
	ssh -o StrictHostKeyChecking=no cp03.$(TF_VAR_dns_domain) echo "Hello World"

.PHONY: kubeadm-init
kubeadm-init:
	ssh cp01.$(TF_VAR_dns_domain) kubeadm init --control-plane-endpoint "api.$(TF_VAR_dns_domain):6443" --upload-certs --pod-network-cidr "192.168.0.0/16"
	ssh cp01.$(TF_VAR_dns_domain) systemctl enable kubelet.service

.PHONY: kubeadm-copy-config
kubeadm-copy-config: ## Copy Kubernetes admin config from cp01 to the local machine
	scp cp01.$(TF_VAR_dns_domain):/etc/kubernetes/admin.conf /root/.kube/config

.PHONY: kubeadm-join-masters
kubeadm-join-masters:
	ssh cp02.$(TF_VAR_dns_domain) $$(ssh cp01.$(TF_VAR_dns_domain) kubeadm token create --ttl 1h --print-join-command --certificate-key "$$(ssh cp01.$(TF_VAR_dns_domain) kubeadm init phase upload-certs --upload-certs | tail -1)" | tail -1)
	ssh cp02.$(TF_VAR_dns_domain) systemctl enable kubelet.service
	ssh cp03.$(TF_VAR_dns_domain) $$(ssh cp01.$(TF_VAR_dns_domain) kubeadm token create --ttl 1h --print-join-command --certificate-key "$$(ssh cp01.$(TF_VAR_dns_domain) kubeadm init phase upload-certs --upload-certs | tail -1)" | tail -1)
	ssh cp03.$(TF_VAR_dns_domain) systemctl enable kubelet.service

.PHONY: kubectl-remove-first-master-taints
kubectl-remove-first-master-taints:
	kubectl taint nodes cp01.$(TF_VAR_dns_domain) node-role.kubernetes.io/master-

.PHONY: kubectl-remove-all-master-taints
kubectl-remove-all-master-taints:
	kubectl taint nodes --all node-role.kubernetes.io/master- || true

.PHONY: kubectl-delete-wrong-subnet
kubectl-delete-wrong-subnet:
	kubectl get pods --all-namespaces -o wide | grep 10.85. | awk '{print "-n " $$1 " " $$2}' | xargs -L 1 kubectl delete pod

.PHONY: kubectl-prepare-hcloud-csi
kubectl-prepare-hcloud-csi:
	kubectl -n kube-system create secret generic --from-literal token=$CLOUD_TOKEN --dry-run=client -o yaml hcloud-csi | kubectl apply -f -

.PHONY: kubernetes-install
kubernetes-install: ssh-init-hosts kubeadm-init kubeadm-copy-config kubectl-remove-first-master-taints kubectl-prepare-hcloud-csi flux-bootstrap kubeadm-join-masters kubectl-remove-all-master-taints kubectl-delete-wrong-subnet
